# Generated by roxygen2: do not edit by hand

export(assertHE_example)
export(check_init)
export(check_markov_trace)
export(check_trans_prob_array)
export(check_trans_prob_mat)
export(create_prompt)
export(extract_function_name)
export(find_files)
export(find_folder_function_definitions)
export(find_function_calls_in_file)
export(find_function_calls_in_folder)
export(find_function_definitions)
export(find_next_vector_element)
export(find_previous_vector_element)
export(get_active_functions)
export(get_file_cheers_classifications)
export(get_folder_cheers_classifications)
export(get_foo_coverage)
export(get_function_data)
export(get_roxygen_description)
export(identify_dependencies)
export(locate_funcs)
export(plotNetwork)
export(plot_PSA_stability)
export(source_funcs)
export(source_lines)
export(summarise_function_from_arguments_and_body)
export(summarise_function_with_LLM)
export(summarise_model)
export(visualise_project)
export(wrap_string)
import(assertthat)
import(dplyr)
importFrom(covr,file_coverage)
importFrom(dplyr,group_by)
importFrom(dplyr,lead)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,summarise)
importFrom(flextable,body_add_flextable)
importFrom(flextable,flextable)
importFrom(flextable,width)
importFrom(htmltools,a)
importFrom(igraph,V)
importFrom(igraph,degree)
importFrom(igraph,graph_from_data_frame)
importFrom(knitr,kable)
importFrom(methods,formalArgs)
importFrom(officer,body_add_par)
importFrom(officer,read_docx)
importFrom(roxygen2,parse_file)
importFrom(rstudioapi,navigateToFile)
importFrom(stats,na.omit)
importFrom(utils,capture.output)
importFrom(utils,getParseData)
importFrom(visNetwork,visEdges)
importFrom(visNetwork,visNetwork)
importFrom(visNetwork,visOptions)
